==> pyside-setup-opensource-src-5.14.1.zip: pyside-setup-opensource-src-5.14.1/sources/shiboken2/tests/samplebinding/echo_test.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Test cases for <add-function> with const char* as argument'''

import unittest

from sample import Echo

class TestEcho(unittest.TestCase):
    '''Simple test case for Echo.echo'''

    def testEcho(self):
        '''Test function added with const char * as arg'''
        x = 'Foobar'
        y = Echo().echo(x)
        self.assertEqual(x, y)

    def testCallOperator(self):
        e = Echo()
        self.assertEqual(e("Hello", 3), "Hello3");
if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-5.15.18.zip: pyside-setup-opensource-src-5.15.18/sources/shiboken2/tests/samplebinding/echo_test.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Test cases for <add-function> with const char* as argument'''

import os
import sys
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from shiboken_paths import init_paths
init_paths()

from sample import Echo

class TestEcho(unittest.TestCase):
    '''Simple test case for Echo.echo'''

    def testEcho(self):
        '''Test function added with const char * as arg'''
        x = 'Foobar'
        y = Echo().echo(x)
        self.assertEqual(x, y)

    def testCallOperator(self):
        e = Echo()
        self.assertEqual(e("Hello", 3), "Hello3");
if __name__ == '__main__':
    unittest.main()
